pyramid_fullauth
================

.. image:: https://pypip.in/v/pyramid_fullauth/badge.png
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: Latest PyPI version

.. image:: https://readthedocs.org/projects/pyramid_fullauth/badge/?version=v0.4.1
    :target: https://readthedocs.org/projects/pyramid_fullauth/?badge=v0.4.1
    :alt: Documentation Status

.. image:: https://pypip.in/d/pyramid_fullauth/badge.png
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: Number of PyPI downloads

.. image:: https://pypip.in/wheel/pyramid_fullauth/badge.png
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: Wheel Status

.. image:: https://pypip.in/egg/pyramid_fullauth/badge.png
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: Egg Status

.. image:: https://pypip.in/license/pyramid_fullauth/badge.png
    :target: https://pypi.python.org/pypi/pyramid_fullauth/
    :alt: License

Pyramid fullauth's goal is to provide full plug-in registration functionality for pyramid, with user managing

Package status
--------------

.. image:: https://travis-ci.org/fizyk/pyramid_fullauth.png?branch=v0.4.1
    :target: https://travis-ci.org/fizyk/pyramid_fullauth
    :alt: Tests

.. image:: https://coveralls.io/repos/fizyk/pyramid_fullauth/badge.png?branch=v0.4.1
    :target: https://coveralls.io/r/fizyk/pyramid_fullauth?branch=v0.4.1
    :alt: Coverage Status

.. image:: https://requires.io/github/fizyk/pyramid_fullauth/requirements.svg?tag=v0.4.1
     :target: https://requires.io/github/fizyk/pyramid_fullauth/requirements/?tag=v0.4.1
     :alt: Requirements Status

Package resources
-----------------

* Bug tracker: https://github.com/fizyk/pyramid_fullauth/issues
* Documentation: http://pyramid-fullauth.readthedocs.org/
* PyPI: https://pypi.python.org/pypi/pyramid_fullauth

Installation
------------

``pip install pyramid_fullauth``

or add **pyramid_fullauth** to your **setup.py** requirements.


Tests
-----

You'll need: packages defined in extra_requires[tests] to run tests, and then:

``py.test``
